@@ -1,6 +1,6 @@
 #ifndef lint
 static char const 
-yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bde Exp $";
+yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28.2.1 2001/07/19 05:46:39 peter Exp $";
 #endif
 #include <stdlib.h>
 #define YYBYACC 1
@@ -11,7 +11,11 @@ yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bd
 #define yyclearin (yychar=(YYEMPTY))
 #define yyerrok (yyerrflag=0)
 #define YYRECOVERING() (yyerrflag!=0)
+#if defined(__cplusplus) || __STDC__
+static int yygrowstack(void);
+#else
 static int yygrowstack();
+#endif
 #define YYPREFIX "yy"
 #line 46 "../../amd/conf_parse.y"
 #ifdef HAVE_CONFIG_H
@@ -60,7 +64,7 @@ static char *header_section = NULL; /* start with no header section */
 typedef union {
 char *strtype;
 } YYSTYPE;
-#line 64 "y.tab.c"
+#line 68 "y.tab.c"
 #define YYERRCODE 256
 #define LEFT_BRACKET 257
 #define RIGHT_BRACKET 258
@@ -229,7 +233,7 @@ yyerror(const char *s)
   exit(1);
   return 1;	/* to full compilers that insist on a return statement */
 }
-#line 233 "y.tab.c"
+#line 237 "y.tab.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
 static int yygrowstack()
 {
@@ -476,7 +480,7 @@ case 15:
 		  }
 		}
 break;
-#line 480 "y.tab.c"
+#line 484 "y.tab.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
