@@ -1,23 +1,37 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd4.2"
+#define HOST_OS "freebsd4.4"
 #define HOST_OS_NAME "freebsd4"
-#define HOST_OS_VERSION "4.2"
+#define HOST_OS_VERSION "4.4"
 #define HOST_ARCH "i386"
-#define HOST_NAME "dummy.mcl.cs.columbia.edu"
+#define HOST_NAME "a-freebsd44.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu Dec 14 12:28:49 EST 2000"
+#define CONFIG_DATE "Wed Nov 14 17:55:01 EST 2001"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.5s3"
+#define VERSION "6.0.8s1"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.5s3"
+#define VERSION "6.0.8s1"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "4.2"
+#define STDC_HEADERS 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_SYS_STAT_H 1
+#define HAVE_STDLIB_H 1
+#define HAVE_STRING_H 1
+#define HAVE_MEMORY_H 1
+#define HAVE_STRINGS_H 1
+#define HAVE_INTTYPES_H 1
+#define HAVE_UNISTD_H 1
+#define HAVE_DLFCN_H 1
+#define HOST_HEADER_VERSION "4.4"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
-#define STDC_HEADERS 1
+#define HAVE_UNISTD_H 1
+#define HAVE_FORK 1
+#define HAVE_VFORK 1
+#define HAVE_WORKING_VFORK 1
+#define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
@@ -238,6 +252,7 @@
 #define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
 #define HAVE_LONG_FILE_NAMES 1
+#define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
@@ -257,15 +272,10 @@
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
-#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
-#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
-#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
-#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
-#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
@@ -335,5 +345,4 @@
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
-#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
