@@ -1,6 +1,6 @@
 #ifndef lint
 static char const 
-yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bde Exp $";
+yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28.2.1 2001/07/19 05:46:39 peter Exp $";
 #endif
 #include <stdlib.h>
 #define YYBYACC 1
@@ -11,7 +11,11 @@ yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bd
 #define yyclearin (yychar=(YYEMPTY))
 #define yyerrok (yyerrflag=0)
 #define YYRECOVERING() (yyerrflag!=0)
+#if defined(__cplusplus) || __STDC__
+static int yygrowstack(void);
+#else
 static int yygrowstack();
+#endif
 #define YYPREFIX "yy"
 #line 46 "../../fsinfo/fsi_gram.y"
 #ifdef HAVE_CONFIG_H
@@ -49,7 +53,7 @@ typedef union {
 	fsi_mount *m;
 	fsmount *f;
 } YYSTYPE;
-#line 53 "y.tab.c"
+#line 57 "y.tab.c"
 #define YYERRCODE 256
 #define tARCH 257
 #define tAS 258
@@ -800,7 +804,7 @@ case 56:
 #line 434 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); }
 break;
-#line 804 "y.tab.c"
+#line 808 "y.tab.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
